/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.com). All Rights Reserved.
 *
 * This software is the property of WSO2 Inc. and its suppliers, if any.
 * Dissemination of any information or reproduction of any material contained
 * herein in any form is strictly forbidden, unless permitted by WSO2 expressly.
 * You may not alter or remove any copyright or other notice from copies of this content."
 */

import React, { FunctionComponent, ReactElement } from "react";
import { Divider, Button, Icon } from "semantic-ui-react";

interface VerticalStrepProps {
    stepTitle: string;
    stepContent: any;
    hasPrevious: boolean;
    hasNext: boolean;
    isFinalStep: boolean;
    isComplete: boolean;
    isCurrentStep: boolean;
    step: number;
    isInitial: boolean;
    isActiveStep: boolean;
    handleCompleteStep: (key: number) => void;
    handlePreviousStep: (key: number) => void;
    isNextEnabled: boolean;
    isSidePanelOpen: boolean;
}

export const VerticalStep: FunctionComponent<VerticalStrepProps> = (
    props: VerticalStrepProps
): ReactElement => {

    const {
        stepTitle,
        stepContent,
        hasPrevious,
        hasNext,
        isFinalStep,
        handleCompleteStep,
        handlePreviousStep,
        step,
        isComplete,
        isInitial,
        isActiveStep,
        isCurrentStep,
        isNextEnabled,
        isSidePanelOpen
    } = props;
    
    return (
        <div className={ `quick-start-step ${isComplete && !isActiveStep ? "complete" : ""} ${!isInitial 
            && !isCurrentStep && !isComplete && !isActiveStep ? "initial" : ""} ` }>
            <div className={ `step-content-container ${ isSidePanelOpen ? "side-panel-visible" : "" }` }>
                <h3>{ stepTitle }</h3>
                <div className="step-content">
                    { stepContent }
                    <Divider hidden/>
                    <div>
                        { hasPrevious && !isFinalStep &&
                            <Button onClick={ () => {
                                handlePreviousStep(step);
                            } } size="tiny" className="step-previous">Previous</Button>
                        }
                        { hasNext &&
                            <Button disabled={ isNextEnabled } onClick={ () => {
                                handleCompleteStep(step);
                            } } size="tiny" primary>Next</Button>
                        }
                        { 
                            // TODO : Move this out of step content
                            !hasNext &&
                            <Button floated="left" className="api-ref" size="tiny" basic color="blue">
                                SDK API Reference <Icon className="ml-1" name="external"/>
                            </Button>
                        }
                    </div>
                    <Divider hidden/>
                </div>
            </div>
        </div>
    )
}
